@@ -132,10 +132,8 @@ print.summary.fii <- local({
       if(!is.null(x$printable)) {
         nvalues <- length(x$printable)
         nheader <- length(x$header)
-        if(nvalues == 1) {
-          splat(paste(paste0(x$header, ":\t"), x$printable))
-        } else if(nvalues == nheader) {
-          for(i in 1:nheader) {
+        if(nvalues == 1 || nvalues == nheader) {
+          for(i in 1:nvalues) {
             hdi <- x$header[i]
             xpi <- x$printable[[i]]
             if(!is.list(xpi) && length(xpi) == 1) {
@@ -201,6 +199,27 @@ reach.fii <- function(x, ..., epsilon=0) {
   return(ir)
 }
 
+hardcoredist <- function(x, ...) {
+  UseMethod("hardcoredist")
+}
+
+hardcoredist.fii <- function(x, ..., epsilon=0) {
+  inte <- x$interaction
+  coeffs <- x$coefs
+  Vnames <- x$Vnames
+  if(is.poisson.interact(inte))
+    return(0)
+  # get 'hardcore' function from interaction object
+  hardcore <- inte$hardcore
+  if(is.null(hardcore) || !is.function(hardcore))
+    return(0)
+  # apply 'hardcore' function using fitted coefficients
+  h <- hardcore(inte, coeffs[Vnames], epsilon=epsilon)
+  if(is.na(h) || is.null(h))
+    h <- 0
+  return(as.numeric(h))
+}
+
 plot.fii <- function(x, ...) {
   inte <- x$interaction
   if(is.poisson.interact(inte)) {
